@@ -30,7 +30,7 @@ class VkontakteManager(models.Manager):
 
     def get_by_url(self, url):
         '''
-        Return vkonakte group by group url
+        Return vkonakte object by url
         '''
         m = re.findall(r'(?:http://)?vk.com/(.+)/?', url)
         if not len(m):
@@ -40,7 +40,7 @@ class VkontakteManager(models.Manager):
 
     def get_by_slug(self, slug):
         '''
-        Return User of Group by slug
+        Return User, Group, Application by slug
         '''
         try:
             assert self.model.slug_prefix and slug.startswith(self.model.slug_prefix)
@@ -161,7 +161,7 @@ class VkontakteModel(models.Model):
 
     def _substitute(self, old_instance):
         '''
-        Substitute new user with old one while updating in method Manager.get_or_create_from_instance()
+        Substitute new instance with old one while updating in method Manager.get_or_create_from_instance()
         Can be overrided in child models
         '''
         self.id = old_instance.id
